pub struct PlannerConfig {
pub max_candidate_ratio: f32,
pub max_candidates: u32,
}Expand description
Configuration for candidate planning / bailout.
Fields
max_candidate_ratio: f32If an upper bound on candidates exceeds this ratio of the corpus, bail out.
Note: we estimate using (\sum_t df(t)), which is an upper bound (can exceed N).
max_candidates: u32If an upper bound on candidates exceeds this absolute count, bail out.